@@ -605,10 +605,8 @@ xmlns:xlink="http://www.w3.org/1999/xlink"/>"""
     #
     # Note that RuntimeErrors create their one headers and pages and thus should come before this: Now's too late
     # for HTML-Error pages.
-    request.emit_http_headers([
-      'Content-Type: application/vnd.oasis.opendocument.text',
-      'Content-Disposition: attachment; filename="%s"' % (filenameASCII)
-    ])
+    request.headers.add('Content-Type','application/vnd.oasis.opendocument.text')
+    request.headers.add('Content-Disposition: attachment','filename="%s"'  % (filenameASCII))
 
     # send data (without 'rb' the windows version doesn't work at all!)
     shutil.copyfileobj( open( pathToZIP, 'rb' ), request, 8192 )
